#!/bin/bash

######################################################################
#                                                                    #
#  This file contains the commands used to compile the GLPK JNI in   #
#  Linux. This file can be executed as a script if the 'HOME'        #
#  variables are changed to their appropriate values.                #
#                                                                    #
#     - Jeremiah Wright                                              #
#                                                                    #
######################################################################


# Note: This script worked successfully on a 64 bit version of Kubuntu
# using gcc 4.1.3.

function check_exit_code {

    EXIT_CODE=$?

    if [ $EXIT_CODE -ne 0 ]; then
	echo "Exit code: $EXIT_CODE"
	exit $?
    fi

}


# Specifying home of the Systems Biology Research Tool
SBRT_HOME=$HOME/software/sbrt/sbrt-1.3.0

# Specifying home of Java
JAVA_HOME=/usr/lib/jvm/java-1.5.0-sun-1.5.0.13

# Specifying home of GLPK
GLPK_HOME=$SBRT_HOME/external_software/glpk-4.8

# Moving to JAVA source root
cd $SBRT_HOME/external_software/glpk_jni/java
check_exit_code

# Compling java files
echo -n 'Compiling and building JAR file ... '

$JAVA_HOME/bin/javac -d classes -classpath src @java_files.txt
check_exit_code

# Creating JAR file
cd classes
check_exit_code

$JAVA_HOME/bin/jar -cf $SBRT_HOME/lib/glpk.jar org
check_exit_code

echo DONE

function make_lib {

    GCC_OPT=$1
    LD_OPT=$2

    # Creating C header file
    $JAVA_HOME/bin/javah -classpath $SBRT_HOME/lib/glpk.jar org.gnu.glpk.GlpkSolver

    echo -n 'Compiling ... '

    # Compiling the C code
    gcc -c \
	$GCC_OPT \
	-fPIC \
	-trigraphs \
	-shared \
	-O2 \
	-I $JAVA_HOME/include/ \
	-I $JAVA_HOME/include/linux/ \
	-I $GLPK_HOME/include/ \
	-c $GLPK_HOME/src/*.c glpk_jni.c
    check_exit_code

    echo DONE

    # Creating the shared object library
    echo -n 'Linking ... '

    ld -fPIC -shared *.o -o libglpk_jni.so $LD_OPT
    check_exit_code

    echo DONE

    # Cleaning up
    rm *.o &> /dev/null
}


# Moving to the 64 bit C source root
cd $SBRT_HOME/external_software/glpk_jni/c_for_64_bit_linux
check_exit_code

# Creating dynamic library
echo
echo Building 64 bit C library
make_lib '-march=x86-64 -m64' '-melf_x86_64'
check_exit_code
