#!/bin/bash

SBRT_HOME=$HOME/wright/sbrt-1.2.2


function check_exit_code {

    EXIT_CODE=$?

    if [ $EXIT_CODE -ne 0 ]; then
	echo "Exit code: $EXIT_CODE"
	exit
    fi


}

function make_JNI_header {

    javah -classpath $SBRT_HOME/lib/glpk.jar org.gnu.glpk.GlpkSolver

}

function compile {

    ARCH=$1

    BIT_FLAG=$2

    rm *.o &> /dev/null

    gcc -c -arch $ARCH $BIT_FLAG -fPIC -trigraphs -shared -O2 \
	-I /Developer/SDKs/MacOSX10.5.sdk/System/Library/Frameworks/JavaVM.framework/Headers/ \
	-I ../../glpk-4.8/include/ -I /Developer/SDKs/MacOSX10.5.sdk/usr/include/ \
	-I /Developer/SDKs/MacOSX10.5.sdk/usr/include/local \
	../../glpk-4.8/src/*.c glpk_jni.c
    check_exit_code

    ld -r -arch $ARCH -o libglpk_jni.o *.o
    check_exit_code

    gcc -dynamiclib -o ${ARCH}.dylib libglpk_jni.o -arch $ARCH $BIT_FLAG
    check_exit_code

    rm *.o &> /dev/null

}

if [[ $# -ne 0 ]]; then
    echo "usage: compile_mac.sh"
    exit
fi

cd $SBRT_HOME/external_software/glpk_jni/c_for_32_bit_mac_os_x

make_JNI_header

compile i386 -m32
compile ppc  -m32

cd $SBRT_HOME/external_software/glpk_jni/c_for_64_bit_mac_os_x

make_JNI_header

compile x86_64 -m64
compile ppc64  -m64

cd ..

lipo -create \
    -arch i386   c_for_32_bit_mac_os_x/i386.dylib   \
    -arch ppc    c_for_32_bit_mac_os_x/ppc.dylib    \
    -arch x86_64 c_for_64_bit_mac_os_x/x86_64.dylib \
    -arch ppc64  c_for_64_bit_mac_os_x/ppc64.dylib  \
    -output libglpk_jni.dylib