#!/bin/bash

######################################################################
#                                                                    #
#  This file contains the commands used to compile the GLPK JNI in   #
#  Windows. This file can be executed as a script if the 'HOME'      #
#  variables are changed to their appropriate values.                #
#                                                                    #
#     - Jeremiah Wright                                              #
#                                                                    #
######################################################################


function check_exit_code {

    EXIT_CODE=$?

    if [ $EXIT_CODE -ne 0 ]; then
	echo "Exit code: $EXIT_CODE"
	exit $?
    fi

}


# Specifying home of the Systems Biology Research Tool
SBRT_HOME=/home/wright/sbrt-1.3.0

# Specifying home of Java
JAVA_HOME=/cygdrive/c/Program\ Files/Java/jdk1.5.0_14

# Specifying home of GLPK
GLPK_HOME=$SBRT_HOME/external_software/glpk-4.8

# Moving to JAVA source root
cd $SBRT_HOME/external_software/glpk_jni/java
check_exit_code

# Compling java files
echo -n 'Compiling and building JAR file ... '

"$JAVA_HOME\bin\javac" -d classes -classpath src @java_files.txt
check_exit_code

# Creating JAR file
cd classes
check_exit_code

"$JAVA_HOME/bin/jar" -cf glpk.jar org
check_exit_code

cp glpk.jar ../../c_for_32_bit_windows/

echo DONE

function make_lib {

    # Creating C header file
    "$JAVA_HOME/bin/javah" -classpath glpk.jar org.gnu.glpk.GlpkSolver

    echo -n 'Compiling ... '

    # Compiling the C code
    gcc \
	-mno-cygwin \
	-trigraphs \
	-shared \
	-O2 \
	-I "$JAVA_HOME/include" \
	-I "$JAVA_HOME/include/win32" \
	-I $GLPK_HOME/include/ \
	-c $GLPK_HOME/src/*.c glpk_jni.c
    check_exit_code

    echo DONE

    # Creating the shared object library
    echo -n 'Linking ... '

    gcc -shared *.o -o glpk_jni.dll -mno-cygwin -Wl,-add-stdcall-alias
    check_exit_code

    echo DONE

    # Cleaning up
    rm *.o &> /dev/null
}


# Moving to the 32 bit C source root
cd $SBRT_HOME/external_software/glpk_jni/c_for_32_bit_windows
check_exit_code

# Creating dynamic library
echo
echo Building 32 bit C library
make_lib
check_exit_code
