/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel;

import sbrt.kernel.io.*;

/**
 * This interface is used to represent processes.
 * A process is a defined series of actions or operations
 * used to produce a desired result.
 * 
 * @author This interface was written and documented by 
 * Jeremiah Wright while in the Wagner lab.
 *
 * @param <T> the type of result an instance of this
 * interface produces.
 */
public interface KernelProcess<T> {

	/**
	 * Runs this process and adds the generated
	 * results to the provided results manager via
	 * its {@linkplain ResultsManager#addData(Object)} 
	 * method. The method {@linkplain ResultsManager#breakPoint()}
	 * may also be called, depending on the type of
	 * process, but {@linkplain ResultsManager#close()} will
	 * <i>never</i> be called by this process.
	 * 
	 * @param resultsManager the results manager
	 * to which the results will be added.
	 */
    public void run(ResultsManager<T> resultsManager);

}
