/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel.fba.comp;

import sbrt.kernel.fba.Fluxome;
import sbrt.kernel.math.algebra.SparseDoubleMatrix;
import sbrt.kernel.utilities.ProgressMonitor;

/**
 * This interface is used to represent algorithms for identifying steady state
 * cycles in stoichiometric networks.
 * 
 * @author This class was written and documented by Jeremiah Wright
 * while in the Wagner lab.
 * 
 * @param <F> the fluxome type.
 *
 */
public interface CycleComputer<F extends Fluxome> {

    /**
     * Returns a progress monitor for this cycle computer. 
     * @return a progress monitor for this cycle computer. 
     */
    public ProgressMonitor getProgress();

    /**
     * Returns the set of all steady state cycles contained in the provided
     * fluxome.
     * 
     * @param fluxome the fluxome for which all cycles will be returned.
     * 
     * @return the cycle matrix. Column variables are reaction names,
     * and each row represents a steady state cycle.
     */
    public SparseDoubleMatrix<?, String> getCycles(F fluxome);

}
