/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel.fba.proc;

import sbrt.kernel.fba.*;

/**
 * This abstract class is used to represent Flux Balance Analysis processes.
 * 
 * @author This class was written and documented by Jeremiah Wright while in
 * the Wagner lab.
 * 
 * @param <F> the fluxome type. 
 * @param <R> the results type.
 */
public abstract class FbaProcess<F extends Fluxome, R> 
	implements sbrt.kernel.KernelProcess<R> {

	/**
	 * Returns the fluxome used in this process.
	 * @return the fluxome used in this process.
	 */
    public abstract F getFluxome();

    /**
     * Returns a string representation of this process.
     * @return a string representation of this process.
     */
    public String toString() {
        return getClass().getCanonicalName();
    }

}
