/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel.io;

/**
 * This class is a skeleton implemenation of {@linkplain ResultsManager}.
 * 
 * @author This class was written and documented by Jeremiah Wright
 * while in the Wagner lab.
 *
 * @param <R> the result type.
 */
public abstract class AbstractResultsManager<R> implements ResultsManager<R> {

    private boolean closed;

    /**
     * Constructs a new results manager.
     */
    public AbstractResultsManager() {
        closed = false;
    }

    /**
     * Does nothing.
     */
    public void breakPoint() {
    	return;
    }

    /**
     * Closes this results manager. If already closed,
     * invoking this method has no effect.
     */
    public void close() {
        closed = true;
    }

    /**
     * Indicates if this results manager has already been closed.
     * 
     * @return {@code true} if this results manager is closed;
     * {@code false} othewise.
     */
    public boolean isClosed() {
        return closed;
    }

	/**
	 * Returns an empty string.
	 * @return an empty string.
	 */
    public String getName() {
        return "";
    }

    /**
     * Ensures {@code close()} has not already been called. 
     * @throws IllegalStateException if {@code close()} has been called.
     */
    protected void checkState() {
    	
    	if (closed) {
    		String s = "Already closed.";
    		throw new IllegalStateException(s);
    	}
    }
}
