/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel.io;

import java.util.*;

import sbrt.kernel.utilities.*;

/**
 * This class is used to indicate conflicting inputs.
 * 
 * @author This class was written and documented by Jeremiah Wright
 * while in the Wagner lab.
 *
 */
public class ConflictingInputException extends RuntimeException {

	private static final long serialVersionUID = 1L;
	private final UnmodifiableList<?> conflicts;

	/**
	 * Constructs a new conflicting input exception.
	 * 
	 * @param conflicts a list of conflicting inputs.
	 */
    public ConflictingInputException(List<?> conflicts) {
        super("conflicts: " + conflicts);

        // Copying the provided list
        List<Object> temp = new ArrayList<Object>(conflicts.size());
        temp.addAll(conflicts);

        // Storing as unmodifiable
        this.conflicts = new UnmodifiableList<Object>(temp);
    }

    /**
     * Returns the list of conflicting inputs.
     * @return the list of conflicting inputs.
     */
    public UnmodifiableList<?> getConflicts() {
        return conflicts;
    }

}
