/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel.io;

/**
 * This class is used to store a single result that can be easily retrieved.
 * 
 * @author This class was written and documented by Jeremiah Wright
 * while in the Wagner lab.
 *
 * @param <R> the result type.
 */
public class SingleRm<R> extends AbstractResultsManager<R> {

    private R results;

    /**
     * Returns the last result added to this results manager.
     * @return the last result added to this results manager.
     */
    public R getResults() {
        return results;
    }

    /**
     * Adds the provided results to this results manager. If a previous
     * result exists, it will be discarded and replaced with the result
     * provided here.
     * 
     * @param <S> a type extending the primary result type.
     * 
     * @param results the results to be stored.
     */
    public <S extends R> void addData(S results) {
    	
        if (isClosed()) {
            throw new IllegalStateException("already closed");
        }
        
        this.results = results;
    }

}
