/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel.math;

/**
 * This interface is used to represent <i>equivalence testers</i>.
 * 
 * @author This interface was written by Jeremiah Wright while in the
 * Wagner lab.
 *
 * @param <T> the class type. 
 */
public interface EquivTester<T> {
    
    /**
     * Tests the provided objects for equivalence.
     * 
     * @param <A> a type extending T.
     * @param <B> a type extending T.
     * @param o1 an object.
     * @param o2 another object.
     * @return {@code true} if the provided objects are equivalent; 
     * {@code false} otherwise.
     */
    public <A extends T, B extends T> boolean areEquiv(A o1, B o2);
    
}
