/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel.math;

/**
 * This class is used to indicate that a variable is unbounded.
 * 
 * @author This class was written and documented by Jeremiah Wright
 * while in the Wagner lab.
 *
 */
public class UnboundedVariableException extends RuntimeException {

	private static final long serialVersionUID = 1L;
	private final Object variable;

	/**
	 * Constructs a new exception from the provided unbounded variable.
	 * @param variable the unbounded variable.
	 */
    public UnboundedVariableException(Object variable) {
        super(variable.toString());
        this.variable = variable;
    }

    /**
     * Returns the unbounded variable.
     * @return the unbounded variable.
     */
    public Object getVariable() {
        return variable;
    }
}
