/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel.math.algebra;

/**
 * This interface is used to represent mutable matrices.
 *  
 * @author This interface was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 * @param <R> the row index type.
 * @param <C> the column index type.
 * @param <E> the element type.
 */
public interface MatrixBuilder <R, C, E> extends Matrix<R, C, E> {

    /**
     * Removes the row corresponding to the provided 
     * row index.
     * 
     * @param rowIndex the index of the row to be removed.
     */
    public void removeRow(Object rowIndex);

    /**
     * Removes the column corresponding to the provided 
     * column index.
     * 
     * @param columnIndex the index of the column to be removed.
     */
    public void removeColumn(Object columnIndex);

    /**
     * Sets the corresponding elements of this matrix to 
     * those of the provided matrix.
     * 
     * @param m the matrix whose elements are to be copied 
     * into this matrix.
     */
    public void setElements(Matrix<? extends R, ? extends C, ? extends E> m);

    /**
     * Sets the element at the provided row and column indices
     * to the one provided.
     * 
     * @param <X> a type extending the primary row index type.
     * @param <Y> a type extending the primary column index type.
     * @param <Z> a type extending the primary element type.
     * 
     * @param rowIndex the row index.
     * @param columnIndex the column index.
     * @param elementValue the element.
     */
    public <X extends R, Y extends C, Z extends E> void 
    	setElement(X rowIndex, Y columnIndex, Z elementValue);

}
