/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel.math.geom;

/**
 * This class is used to indicate invalid dimensions.
 * 
 * @author This class was written and documented by Jeremiah Wright
 * while in the Wagner lab.
 *
 */
public class DimensionException extends RuntimeException {

	private static final long serialVersionUID = 1L;

    private final int dimension;
    
	/**
	 * Constructs a new dimension exception.
	 * 
	 * @param dimension the invalid dimension.
	 */
    public DimensionException(int dimension) {
        
        super("dimension: " + dimension);

        this.dimension = dimension;
    }

    /**
     * Returns the invalid dimension.
     * @return the invalid dimension.
     */
    public int getDimension() {
        return dimension;
    }

}
