/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel.math.optimization;

/**
 * This enum type is used to represent the sense, or direction,
 * of an optimization problem.
 * 
 * @author This enum type was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 */
public enum OptSense {

	/**
	 * Used to indicate a maximization problem.
	 */
    MAX ("Maximize"),

    /**
     * Used to indicate a minimization problem.
     */
    MIN ("Minimize");

    // The string returned by toString()
    private final String description;

    // Private constructor, to prevent the creation
    // of new instances
    private OptSense(String description) {
        this.description = description;
    }

    /**
     * Returns an appropriate string representation
     * of this optimization sense.
     * 
     * @return an appropriate string representation
     * of this optimization sense.
     */
    public String toString() {
        return description;
    }

}
