/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel.math.optimization;

/**
 * This enum type is used to indicate the status of a program solver.
 * 
 * @author This enum type was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 */
public enum ProgramSolverStatus {

	/**
	 * Used to indicate an optimal solution exists.
	 */
    OPTIMAL ("Optimal"),
    
    /**
     * Used to indicate a feasible solution exists.
     */
    FEASIBLE ("Feasible"),
    
    /**
     * Used to indicate a bounded solution exists.
     */
    BOUNDED ("Bounded"),
    
    /**
     * Used to indicate no feasible solution exists.
     */
    INFEASIBLE ("Infeasible"),
    
    /**
     * Used to indicate no feasible solution exists or the solution is unbounded.
     */
    INFEASIBLE_OR_UNBOUNDED ("Infeasible or Unbounded"),
    
    /**
     * Used to indicate an unbounded solution.
     */
    UNBOUNDED ("Unbounded"),
    
    /**
     * Used to indicate an undefined problem.
     */
    UNDEFINED ("Undefined"),
    
    /**
     * Used to indicate an unknown problem.
     */
    UNKNOWN ("Unknown"),
    
    /**
     * Used to indicate an error has ocurred.
     */
    ERROR ("Error");

    private final String description;

    private ProgramSolverStatus(String description) {
        this.description = description;
    }

    /**
     * Returns an appropriate string representation
     * of this program solver status.
     * 
     * @return an appropriate string representation
     * of this program solver status.
     */
    public String toString() {
        return description;
    }
}
