/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel.math.optimization;

import sbrt.kernel.math.*;

/**
 * This interface is used to represent quadratic program solvers.
 * 
 * @author This interface was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 * @param <R> the row variable type.
 * @param <C> the column variable type.
 */
public interface QuadraticProgramSolver<R, C> extends ProgramSolver<R, C> {

    /**
     * Sets a constraint on the provided quadratic expression of
     * column variables.
     * 
     * @param expression a linear combination of column variables for
     * which the constraint is set.
     * @param c the constraint.
     */
    public void setConstraint(QuadraticExpr<? extends C> expression, Interval c);

    /**
     * Sets the objective function and optimization sense to the provided
     * values.
     * 
     * @param expression a linear combination of column variables from
     * this program solver.
     * @param sense the optimization sense.
     * 
     * @see #setObjectiveFunction(QuadraticExpr)
     * @see #setOptimizationSense(OptSense)
     */
    public void setObjectiveFunction(QuadraticExpr<? extends C> expression,
                                     OptSense sense);

    /**
     * Sets the objective function to the provided quadratic expression of
     * column variables.
     * 
     * @param expression a quadratic expression of column variables from
     * this program solver.
     */
    public void setObjectiveFunction(QuadraticExpr<? extends C> expression);

}
