/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel.math.stat.comp;

import java.util.*;

/**
 * This interface is used to represent correlation statistic computers.
 * 
 * @author This interface was written and documented by Jeremiah Wright
 * while in the Wagner lab.
 * 
 * @param <V> the variable type.
 * @param <T> the correlation result type.
 */
public interface Correlator<V, T extends CorrResult> {

	/**
	 * Computes and returns the correlation statistic of the provided x and y
	 * values. The key sets of the provided maps need not be identical, but only
     * the intersecting values will be considered.
	 * 
	 * @param xValues variables mapped to their values.
	 * @param yValues variables mapped to their values.
	 * 
	 * @return the results of computing the correlation statistic between the
	 * provided x and y values.
	 */
    public T corr(Map<? extends V, Double> xValues, 
                  Map<? extends V, Double> yValues);

	/**
	 * Computes and returns the correlation statistic of the provided x and y
	 * values.
	 * 
	 * @param xValues an ordered collection of values.
	 * @param yValues an ordered collection of values.
	 * 
	 * @return the results of computing the correlation statistic between the
	 * provided x and y values.
	 */
    public T corr(Collection<Double> xValues, Collection<Double> yValues);

	/**
	 * Computes and returns the correlation statistic of the provided x and y
	 * values.
	 * 
	 * @param xValues an array of values.
	 * @param yValues an array of values.
	 * 
	 * @return the results of computing the correlation statistic between the
	 * provided x and y values.
	 */
    public T corr(Double[] xValues, Double[] yValues);

}
