/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel.math.stat.comp;

/**
 * This class is used to compute Kendall's Tau<sub>B</sub> correlation
 * statistic.
 * 
 * @author This class was written and documented by Jeremiah Wright
 * while in the Wagner lab.
 *
 * @param <V> the variable type.
 */
public class KendallTauB<V> extends KendallTau<V> {

    /**
     * Computes and returns the correlation statistic for the provided values.
     * 
     * @param xValues an ordered array of values.
     * @param yValues an ordered array of values.
     * 
     * @return the correlation statistic for the provided values.
     */
    public double getTau(double[] xValues, double[] yValues) {

        int n = xValues.length;
        if (n != yValues.length) {
            String s = "Arrays not the same size.";
            throw new IllegalArgumentException(s);
        }

        // Getting the S value
        double s = getS(xValues, yValues);

        // Getting the tie score for each sorted array
        double u = getTieScore(xValues);
        double v = getTieScore(yValues);

        // Getting primary factor in denominator
        double denomFactor = 0.5 * n * (n - 1);

        return s / (Math.sqrt(denomFactor - u) * Math.sqrt(denomFactor - v));
    }

}
