/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel.utilities;

import java.util.Collection;
import java.util.Iterator;

/**
 * This class is used to represent the logical relationship "and".
 * 
 * @author This class was written and documented by Jeremiah Wright while in the
 *         Wagner lab.
 * 
 * @param <C>
 *            the condition type.
 */
public final class And<C> extends LogicalRelation<C> {

	/**
	 * Constructs a new "and" relationship.
	 * 
	 * @param conditions the conditions.
	 */
    public And(Collection<C> conditions) {
        super(conditions);
    }
    
    /**
     * Indicates if this "and" is equal to the provided object.
     * 
     * @param obj the object for which comparison is made.
     * 
     *  @return {@code true} if the provided object is of type {@code And}
     *  and its conditions of both "ands" are equal; {@code false} otherwise.
     */
    public boolean equals(Object obj) {
        
        if (this == obj) {
            return true;
        }
        
        if (!(obj instanceof And)) {
            return false;
        }
        
        And<?> and = (And) obj;
        
        return getConditions().equals(and.getConditions());
    }
    
    /**
     * Returns a string representation of this "and" relationship.
     * @return a string representation of this "and" relationship.
     */
    public String toString() {
        
        StringBuilder sb = new StringBuilder();
        
        for (Iterator<C> i = iterator(); i.hasNext(); ) {
            
            sb.append(i.next());
            
            if (i.hasNext()) {
                sb.append(" and ");
            }
        }
        
        return sb.toString();
    }
}
