/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel.utilities;

/**
 * This interface is used to represent mutable progress montiors.
 * 
 * @author This interface was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 */
public interface MutableProgressMonitor extends ProgressMonitor {
    /**
     * Causes this progress monitor to increment an internal counter.
     */
    public void increment();

    /**
     * Causes this progress monitor to start monitoring a duration of time. 
     * @throws IllegalStateException if {@code start()} was already called
     * without a subsequent call to {@code stop()}. 
     */
    public void start();

    /**
     * Causes this progress monitor to stop monitoring a duration of time.
     * 
     * @throws IllegalStateException if {@code start()} was never called, or
     * if {@code stop()} has already been called since the last call to
     * {@code start()}.
     * 
     */
    public void stop();

    /**
     * Causes this progress monitor to reset its internal counter to 0.
     */
    public void resetCount();

    /**
     * Returns this progress monitor as an immutable object. This allows
     * the contents of this progress monitor to be queried without the 
     * possibility of modification.
     * 
     * @return this progress monitor as an immutable object.
     */
    public ProgressMonitor asUnmodifiable();

}
