/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.kernel.utilities;

/**
 * This interface is used to represent progress monitors.
 * 
 * @author This interface was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 */
public interface ProgressMonitor {

	/**
	 * Returns the current duration of the process being monitored.
	 * @return the current duration of the process in milliseconds.
	 */
    public long getDuration();

    /**
     * Returns a number indicating the progress of the process being monitored.
     * @return a number indicating the progress of the process being monitored.
     */
    public Number getProgress();

    /**
     * Indicates if this progress monitor has already been started.
     * @return {@code true} if this progress monitor has already been started;
     * {@code false} otherwise.
     */
    public boolean started();

    /**
     * Indicates if this progress monitor has already been stopped.
     * @return {@code true} if this progress monitor has already been stopped;
     * {@code false} otherwise.
     */
    public boolean stopped();
}
