/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell;

import java.io.File;


/**
 * This class is used to return the home directory of the SBRT, that is, the
 * directory in which the SBRT resides.
 * 
 * @author This class was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 */
public class HomeDirectory {
    
    /**
     * Returns the SBRT's home directory.
     * @return the SBRT's home directory.
     */
    public static File get() {
    	
    	String name = System.getProperty("sbrt.home.directory");
    	
    	if (name == null) {
    		String s = "The SBRT's home directory could not be determined. " +
    				   "The option '-Dsbrt.home.directory' must be " +
    				   "supplied to the Java Virtual Machine, and it must " +
    				   "be assigned an appropriate value.";
    		throw new ApplicationException(s);
    	}
    	
        File homeDir = new File(name);
        
        if (!homeDir.isDirectory()) {
        	String s = "The provided value for the SBRT's home directory '" +
        			   name + "' is not a directory. The option " +
        			   "'-Dsbrt.home.directory' must be assigned an " +
        			   "appropriate value when supplied to the Java Virtual " +
        			   "Machine.";
        	throw new ApplicationException(s);
        }
        
        return homeDir;
    }
    
    
}
