/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell;

import java.io.File;


/**
 * This class is used to manage the working directory of the SBRT.
 * 
 * @author This class was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 */
public class WorkingDirectory {

    private static File workingDir;
    
    static {
        workingDir = new File(System.getProperty("user.dir"));
    }
    
    /**
     * Returns the current working directory.
     * @return the current working directory.
     */
    public static File get() {
        return workingDir;
    }
    
    /**
     * Sets the working directory to the provided value.
     * @param workingDir the new working directory.
     * @throws ApplicationException if the provided file is not a directory.
     */
    public static void set(File workingDir) {
        
        if (!workingDir.isDirectory()) {
            String s = "The file '" + workingDir + "' is not a directory.";
            throw new ApplicationException(s);
        }

        WorkingDirectory.workingDir = workingDir;
    
    }
    
    /**
     * Sets the working directory to the provided value.
     * @param workingDir the name of the new working directory.
     * @throws ApplicationException if the specified file is not a directory.
     */
    public static void set(String workingDir) {
        set(new File(workingDir));
    }

    
    
}
