/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.io;

import java.io.File;
import java.io.IOException;

import sbrt.shell.ApplicationException;
import sbrt.shell.WorkingDirectory;

/**
 * This class provides a helper method for SBRT files.
 * 
 * @author This class was written and documented by Jeremiah Wright while in the
 * Wagner lab.
 *
 */
public class AbstractSbrtFile {

    

    /**
     * Returns the canonical name of the specified file.
     * @param fileName the name of the file.
     * @return the canonical name of the specified file.
     * 
     * @see File#getCanonicalPath()
     */
    public static String getCanonicalName(String fileName) {
        
        File f = new File(fileName);

        if (!f.isAbsolute()) {
            f = new File(WorkingDirectory.get() + File.separator + fileName);
        }
        
        try {
            
            return f.getCanonicalPath();

        } catch (IOException e) {
            String s = "The canonical path of '" + fileName + "' could not be determined.";
            throw new ApplicationException(s, e);
        }
        
    }

}
