/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.io;

import java.io.*;

/**
 * This class is used to mimic /dev/null from Unix-like operating systems. An
 * instance of this class discards all data written to it.
 * 
 * @author This class was written and documented by Jeremiah Wright while in the
 *         Wagner lab.
 * 
 */
public class DevNull extends PrintStream {

	
	private static DevNull devNull;
	private static PrintWriter writer;
	
	/**
	 * Returns an instance of this class.
	 * @return an instance of this class.
	 */
	public static DevNull get() {
		
		if (devNull == null) {
			devNull = new DevNull();
		}
		
		return devNull;
	}
	
	/**
	 * Returns an instance of this class wrapped by a print writer.
	 * @return an instance of this class wrapped by a print writer.
	 */
	public static PrintWriter getWriter() {
		
		if (writer == null) {
			writer = new PrintWriter(get(), true); 
		}
		
		return writer;
	}
	
	/**
	 * Constructs new "/dev/null" object.
	 */
    private DevNull() {
        
    	super(new OutputStream() {

        	public void write(int b) {
            	// does nothing
            }
        
        });
    }

}
