/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.io;

import java.io.*;

/**
 * This class is used to represent end-of-file (EOF).
 * 
 * @author This class was written and documented by Jeremiah Wright while in the
 * Wagner lab.
 */
public final class EndOfFile implements Serializable {

    private static final long serialVersionUID = 0L;

    private static EndOfFile eof;

    /**
     * Returns an instance of this class.
     * @return an instance of this class.
     */
    public static EndOfFile get() {
    
    	if (eof == null) {
    		eof = new EndOfFile();
    	}
    	
    	return eof;
    }

    
    /**
     * Indicates if the provided object is an instance of
     * this class.
     * 
     * @param obj the reference object with which to compare.
     * 
     * @return {@code true} if the provided object is an
     * instance of this class; {@code false} otherwise.
     */
    public static final boolean isEof(Object obj) {
        return obj instanceof EndOfFile;
    }
    
    private EndOfFile() {
    	// does nothing
    }
    
    /**
     * Indicates if the provided object is equal to this
     * end-of-file.
     * 
     * @param obj the reference object with which to compare.
     * 
     * @return {@code true} if the provided object is an
     * instance of this class; {@code false} otherwise.
     */
    public boolean equals(Object obj) {
        // All EndOfFile objects are the same
        return obj instanceof EndOfFile;
    }

    /**
     * Returns {@code 0}.
     * @return {@code 0}.
     */
    public int hashCode() {
    	return 0;
    }

}
