/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.io;

/**
 * This class is used to represent file formats.
 * A file format is a particular way to encode 
 * information for storage in a computer file.
 * <P>
 * Instances of this class are immutable.
 * 
 * @author This class was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 */
public class FileFormat {

	/**
	 * Used to denote a plain-text file.
	 */
    public static final FileFormat TEXT = new FileFormat("Text");

    /**
     * Used to denote a plain-text file that has been
     * compressed using the GNU program gzip.
     */
    public static final FileFormat GZIP_TEXT = new FileFormat("GZIP Text");

    /**
     * Used to denote a file containing serialized objects.
     */
    public static final FileFormat SERIALIZED = new FileFormat("Serialized");

    /**
     * Used to denote a file containing serialized objects
     * that has been compressed using the GNU program gzip.
     */
    public static final FileFormat GZIP_SER = new FileFormat("GZIP Serialized");

    // The name of this file format
    private final String name;

    // Private constructor to prevent the creation
    // of new file formats
    private FileFormat(String name) {
        this.name = name;
    }

    /**
     * Returns the name of this file format.
     * @return the name of this file format.
     */
    public String getName() {
        return name;
    }

    /**
     * Returns a string representation of this file format.
     * @return a string representation of this file format.
     */
    public String toString() {
    	return getName();
    }
}
