/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.io;

import java.util.Iterator;

import sbrt.shell.ApplicationException;

/**
 * This class is used to iterate through the lines of a file.
 * 
 * @author This class was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 * 
 * @param <E> the returned type.
 */
public abstract class FileLineIterator<E> implements Iterator<E>{

	/**
	 * Ensures the provided string is the name of a valid
	 * file.
	 * 
	 * @param fileName the name of the file to check for
	 * validity.
	 */
    protected static void checkFile(String fileName) {
    	
        // Creating Java file
        java.io.File f = new java.io.File(fileName);

        if (!f.exists()) {
            String s = "The file '" + f.getAbsolutePath() + "' does not exist.";
            throw new ApplicationException(s);
        }

        if (!f.isFile()) {
            String s = "The file '" + fileName +
                       "' is not a normal file.";
            throw new ApplicationException(s);
        }

        if (!f.canRead()) {
            String s = "The file '" + fileName + "' cannot be read.";
            throw new ApplicationException(s);
        }

    }
    
}
