/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.io;

import java.util.*;

/**
 * This interface is used to represent output files that
 * maps can be written to.
 * 
 * @author This interface was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 * 
 * @param <K> the variable type.
 * @param <V> the value type.
 */
public interface MapOutputFile<K, V> 
	extends OutputFile<Map<? extends K, ? extends V>> {
	
	/**
	 * Returns the set of keys whose values will be
	 * written to this output file when a map is added.
	 * This set acts as a type of filter to control which
	 * values in a map are saved, and which are discarded.
	 * 
	 * @return the set of keys whose values will be
	 * written to this output file when a map is added.
	 */
	public Set<K> getFilterKeys();

	/**
	 * Writes the appropriate values of the provided map 
	 * to this file. The appropriate values are those of the
	 * keys in the set returned by {@linkplain #getFilterKeys()}.
	 * 
	 * @param map the map to be written to this file.
	 * 
	 * @throws IllegalArgumentException if the provided
	 * map does not contain all the keys in the
	 * set returned by {@linkplain #getFilterKeys()}.
	 * 
	 * @throws IllegalStateException if {@code close()}
	 * has already been called.
	 */
	public void addData(Map<? extends K, ? extends V> map);

}
