/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.io;

import java.io.File;

/**
 * This interface is used to represent files.
 * 
 * @author This interface was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 */
public interface SbrtFile {

    /**
     * Closes this file. If this file is already closed, then
     * invoking this method has no effect.
     */
    public void close();

    /**
     * Indicates if this file has already been closed.
     * 
     * @return {@code true} if this file is closed;
     * {@code false} othewise.
     */
    public boolean isClosed();

    /**
     * Returns the original name given to this file.
     * @return the original name given to this file.
     */
    public String getOriginalName();

    /**
     * Returns the canonical name of this file.
     * @return the canonical name of this file.
     * 
     * @see File#getCanonicalPath()
     */
    public String getCanonicalName();
}
