/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.io;

import java.io.FileReader;
import java.io.IOException;

import org.apache.xerces.parsers.DOMParser;
import org.w3c.dom.Document;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

import sbrt.shell.ApplicationException;

/**
 * This class is used to create DOM objects from XML files.
 * 
 * @author This class was written and documented by Jeremiah Wright while in the
 * Wagner lab.
 * 
 */
public class XmlFileFactory {
	
    /**
     * Returns a DOM object for the file with the specified name.
     * 
     * @param xmlFileName the name of the XML file.
     * @return a DOM object for the file with the specified name.
     * @throws ApplicationException if any error occurs while reading or parsing
     * the specified file.
     */
    public static Document getDOM(String xmlFileName) {

        // Ensuring the file exists, and getting its name
        InputFile<String> file = TextInputFile.getBasic(xmlFileName);

        String name = file.getCanonicalName();
        
        file.close();
        
        DOMParser parser = new DOMParser();

        try {

            FileReader fileReader = new FileReader(name);

            InputSource input = new InputSource(fileReader);
            
            parser.parse(input);

        } catch (IOException e) {

            String s =
                    "An error occurred while reading the file '"
                            + name
                            + "'.";
            throw new ApplicationException(s, e);

        } catch (SAXException e) {

            String s =
                    "An error occurred while parsing the file '"
                            + name
                            + "'.";
            throw new ApplicationException(s, e);

        }

        Document dom = parser.getDocument();

        return dom;
    }

}
