/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.mng;

import sbrt.kernel.KernelProcess;

/**
 * This interface is used to represent process managers.
 * A process manager is used to control a {@linkplain sbrt.kernel.KernelProcess}. 
 * The manager is responsible for combining inputs from 
 * different sources and passing this information to a 
 * {@code KernelProcess} in a way it can understand.
 * <P>
 * A process manager is created from a {@code ManagerInput}
 * object. Process managers require a minimum set of key-value 
 * pairs to construct their associated {@code Process}.
 * In addition to this minimum set, a set of optional
 * key-value pairs may also be allowed. If the provided {@code ManagerInput}
 * contains any additional keys beyond the set of required and optional keys,
 * an {@code ApplicationException} will be thrown. 
 * 
 * 
 * @author This interface was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 * @param <K> the key type.
 * @param <V> the value type.
 */
public interface KernelProcessManager<K, V> extends ProcessManager<K, V> {

    /**
     * Returns the process this process manager controls.
     * This method helps maintain the integrity of the shell and 
     * kernel by contractually forcing a process to exist. In other words,
     * this method prevents a process manager from performing
     * process-level operations.
     *  
     * @return the process this process manager controls.
     */
    public KernelProcess<?> getProcess();

}
