/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.text;

/**
 * This class is a concrete implementation of 
 * {@linkplain AppInputFileLineFormat}. The string representation of
 * a line of a process input file is: <p>
 * <i>keyword: value</i>.
 * 
 * @author This class was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 */
public final class AppInputFileLineFormatVersion1
        extends AbstractMapFormat<String, String>
        implements AppInputFileLineFormat {
	
	private final ColonMapEntryFormatV1<String, String> entryFormat;
	private final PipeSetFormat<String> setFormat;
	private final PipeListFormat<String> listFormat;
	
	/**
	 * Constructs a new process input file line
	 * format.
	 */
    public AppInputFileLineFormatVersion1() {

    	StringFormat f = new StringFormat();
        
        // Creating formats
        entryFormat = ColonMapEntryFormatV1.getBasic();
        setFormat = new PipeSetFormat<String>(f);
        listFormat = new PipeListFormat<String>(f);
    }

    /**
     * Returns the format used for variable-value pairs.
     * @return the format used for variable-value pairs.
     */
    public ColonMapEntryFormatV1<String, String> getMapEntryFormat() {
        return entryFormat;
    }

    /**
     * Returns the format used for sets of variables.
     * @return the format used for sets of variables.
     */
    public PipeSetFormat<String> getSetFormat() {
        return setFormat;
    }

    /**
     * Returns the format used for lists of values.
     * @return the format used for lists of values.
     */
    public PipeListFormat<String> getListFormat() {
        return listFormat;
    }

}
