/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.text;

/**
 * This interface is used to represent a format for boolean
 * values.
 * 
 * @author This interface was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 */
public interface BooleanFormat extends SimpleFormat<Boolean> {

	/**
	 * Returns a formatted string representation of the
	 * provided boolean value.
	 * 
	 * @param b the boolean value to be formatted. 
	 * 
	 * @return a formatted string representation of the
	 * provided boolean value.
	 */
    public String format(Boolean b);

	/**
	 * Returns a formatted string representation of the
	 * provided boolean value.
	 * 
	 * @param b the boolean value to be formatted. 
	 * 
	 * @return a formatted string representation of the
	 * provided boolean value.
	 */
    public String format(boolean b);

    /**
     * Parses the provided string and returns its 
     * corresponding boolean value.
     * 
     * @param b the string to be parsed.
     * 
     * @return the boolean value corresponding to the
     * provided string.
     */
    public Boolean parse(String b);

    /**
     * Parses the provided string and returns its 
     * corresponding boolean value.
     * 
     * @param b the string to be parsed.
     * 
     * @return the boolean value corresponding to the
     * provided string.
     */
    public boolean parsePrimitive(String b);

}
