/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.text;

import java.util.Collection;

/**
 * This interface is used to represent collection formats.
 * 
 * @author This interface was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 * 
 * @param <E> the type of element.
 */
public interface CollectionFormat<E> 
	extends SimpleFormat<Collection<? extends E>> {

	/**
	 * Returns a formatted string representation of the
	 * provided collection.

	 * @param c the collection to be formatted.
	 * 
	 * @return a formatted string representation of the
	 * provided collection.
	 */
    public String format(Collection<? extends E> c);

    /**
     * Parses the provided string and returns its 
     * corresponding collection of elements.
     * 
     * @param source the string to be parsed.
     * 
     * @return the collection of elements 
     * corresponding to the provided string. 
     */
    public Collection<E> parse(String source);

    /**
     * Returns the format object used for 
     * the elements of this collection format.
     * 
     * @return the format object used for 
     * the elements of this collection format.
     */
    public SimpleFormat<E> getElementFormat();
}
