/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.text;

import sbrt.shell.*;

/**
 * This exception type is used to indicate a formatting error
 * has ocurred. If a string is unparsable because it does
 * not conform to the expected format, this exception should
 * be thrown.
 * 
 * @author This class was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 */
public class FormatException extends ApplicationException {

	private static final long serialVersionUID = 1L;

	/**
	 * Constructs a new format exception with
	 * the provided error message.
	 * 
	 * @param message a complete, informative, 
	 * well-formed sentence describing the error that 
	 * ocurred (which is saved for later retrieval by 
	 * the {@linkplain Throwable#getMessage()} method).
	 */
	public FormatException(String message) {
        super(message);
    }

	/**
	 * Constructs a new format exception with
	 * the provided error message and cause.
	 * 
	 * @param message a complete, informative, 
	 * well-formed sentence describing the error that 
	 * ocurred (which is saved for later retrieval by 
	 * the {@linkplain Throwable#getMessage()} method).
	 * 
	 * @param cause the cause (which is saved for later 
	 * retrieval by the {@linkplain Throwable#getCause()} method). 
	 * (A null value is permitted, and indicates that the 
	 * cause is nonexistent or unknown.)
	 */
    public FormatException(String message, Throwable cause) {
        super(message, cause);
    }

}
