/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.text;

import java.util.*;

/**
 * This interface is used to represent {@code LinkedHashSet}
 * formats. Ideally, this interface would represent the format
 * of ordered sets, without reference to their implementation
 * details; but unfortunately, the only type of ordered set
 * in Java is the {@code LinkedHashSet}.
 * 
 * @author This interface was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 * 
 * @param <E> the type of element.
 */
public interface LinkedHashSetFormat<E> 
	extends Formatter<Set<? extends E>>, Parser<LinkedHashSet<E>> {

	/**
	 * Returns a formatted string representation of the
	 * provided set.

	 * @param set the set to be formatted.
	 * 
	 * @return a formatted string representation of the
	 * provided set.
	 */
    public String format(Set<? extends E> set);

    /**
     * Parses the provided string and returns its 
     * corresponding collection of elements as a 
     * {@code LinkedHashSet}.
     * 
     * @param set the string to be parsed.
     * 
     * @return the set of elements 
     * corresponding to the provided string. 
     */	
    public LinkedHashSet<E> parse(String set);

    /**
     * Returns the formatter for 
     * the elements of this set format.
     * 
     * @return the formatter for 
     * the elements of this set format.
     */
    public Formatter<E> getElementFormatter();

    /**
     * Returns the parser for 
     * the elements of this set format.
     * 
     * @return the parser for 
     * the elements of this set format.
     */
    public Parser<E> getElementParser();


}
