/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.text;

/**
 * This class is a concrete implementation of {@linkplain LongFormat}.
 * 
 * @author This class was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 */
public class LongFormatV1 implements LongFormat {

	/**
	 * Returns a formatted string representation of the
	 * provided long. See
	 * {@linkplain java.lang.Long#toString(long)} for the 
	 * exact formatting rules.
	 * 
	 * @param i the long to be formatted.
	 * 
	 * @return a formatted string representation of the
	 * provided long.
	 */
    public String format(Long i) {
        return i.toString();
    }

    /**
     * Parses the provided string and returns its 
     * corresponding long. See
     * {@linkplain java.lang.Long#valueOf(String)}
     * for the exact formatting rules.
     * 
     * @param i the string to be parsed.
     * 
     * @return the long corresponding to the provided string. 
     * 
     * @throws FormatException if the provided string
     * is not parsable as a long.
     * 
     * @throws NullPointerException if the provided 
     * argument is {@code null}.
     */
    public String format(long i) {
        return Long.toString(i);
    }

    /**
     * Parses the provided string and returns its 
     * corresponding long. See
     * {@linkplain java.lang.Long#valueOf(String)}
     * for the exact formatting rules.
     * 
     * @param i the string to be parsed.
     * 
     * @return the long corresponding 
     * to the provided string. 
     * 
     * @throws FormatException if the provided string
     * is not parsable as a long.
     * 
     * @throws NullPointerException if the provided 
     * argument is {@code null}.
     */
    public Long parse(String i) {
    	
    	// Parsing as primitive
    	long x = parsePrimitive(i);
    	
    	// Returning Long
        return Long.valueOf(x);
    }

    /**
     * Parses the provided string and returns its 
     * corresponding long. See
     * {@linkplain java.lang.Long#valueOf(String)}
     * for the exact formatting rules.
     * 
     * @param i the string to be parsed.
     * 
     * @return the long corresponding 
     * to the provided string. 
     * 
     * @throws FormatException if the provided string
     * is not parsable as a long.
     * 
     * @throws NullPointerException if the provided 
     * argument is {@code null}.
     */
    public long parsePrimitive(String i) {

        try {
        	
            return Long.parseLong(i);
            
        } catch (Throwable t) {
            String s = "'" + i + "' is not parsable as a whole number.";
            throw new FormatException(s, t);
        }
    }

}

