/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.text;

/**
 * This interface is used to represent simple formats.
 * A simple format is used to "convert" a single formatted
 * string into a single object, and vice-versa. This interface
 * is very similar to the abstract Java class 
 * {@code java.text.Format} but with fewer implementation
 * restrictions.
 * <P>
 * The methods {@code format(Object)} and {@code parse(String)}
 * are inverse functions in the mathematical sense. For
 * an object {@code obj} and format {@code f}, the statement
 * {@code f.parse(f.format(obj)).equals(obj)}
 * must return {@code true}.
 * 
 * @author This interface was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 * 
 * @param <T> the type of object this format applies to.
 */
public interface SimpleFormat<T> extends Format, Formatter<T>, Parser<T> {

	// No other methods
	
}
