/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.text;

import java.util.*;

/**
 * This class contains a set of characters that could be considered as <i>special</i>
 * in some situations.
 * 
 * @author This class was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 */
public final class SpecialChars {

    /**
     * :
     */
    public static final char COLON = ':';
    
    /**
     * ;
     */
    public static final char SEMICOLON = ';';
    
    /**
     * ,
     */
    public static final char COMMA = ',';
    
    /**
     * |
     */
    public static final char PIPE = '|';
   
    /**
     * #
     */
    public static final char HASH = '#';
    
    /**
     * ~
     */
    public static final char TILDE = '~';
    
    /**
     * *
     */
    public static final char ASTERICK = '*';
    
    /**
     * +
     */
    public static final char PLUS = '+';
    
    /**
     * =
     */
    public static final char EQUALS = '='; 
    
    /**
     * >
     */
    public static final char GREATER_THAN = '>';
    
    /**
     * <
     */
    public static final char LESS_THAN = '<';
    
    /**
     * (
     */
    public static final char LEFT_PAREN = '('; 
    
    /**
     * )
     */
    public static final char RIGHT_PAREN = ')';
    
    /**
     * [
     */
    public static final char LEFT_BRACKET = '[';
    
    /**
     * ]
     */
    public static final char RIGHT_BRACKET = ']';
    
    /**
     * {
     */
    public static final char LEFT_BRACE = '{';
    
    /**
     * {
     */
    public static final char RIGHT_BRACE = '}'; 
    
    /**
     * ^
     */
    public static final char CARET = '^';
    
    /**
     * &amp;
     */
    public static final char AMPERSAND = '&';
    
    /**
     * !
     */
    public static final char EXCLAMATION = '!';
    
    /**
     * {@code @}
     */
    public static final char AT = '@';
    
    /**
     * $
     */
    public static final char DOLLAR = '$';
    
    /**
     * %
     */
    public static final char PERCENT = '%';
    
    /**
     * -
     */
    public static final char DASH = '-';
    
    /**
     *{@code /}
     */
    public static final char FORWARD_SLASH = '/';
    
    /**
     * \
     */
    public static final char BACK_SLASH = '\\';
    
    /**
     * ?
     */
    public static final char QUESTION = '?';
    
    /**
     * .
     */
    public static final char DOT = '.';
    
    /**
     * Returns an array of the characters contained in this class.
     * @return an array of the characters contained in this class.
     */
    public static char[] getArray() {
        
        return new char[] {  COLON,
                             SEMICOLON,
                             COMMA,
                             PIPE,
                             HASH,
                             TILDE,
                             ASTERICK,
                             PLUS,
                             EQUALS,
                             GREATER_THAN,
                             LESS_THAN,
                             LEFT_PAREN,
                             RIGHT_PAREN,
                             LEFT_BRACKET,
                             RIGHT_BRACKET,
                             LEFT_BRACE,
                             RIGHT_BRACE,
                             CARET,
                             AMPERSAND,
                             EXCLAMATION,
                             AT,
                             DOLLAR,
                             PERCENT,
                             DASH,
                             FORWARD_SLASH,
                             BACK_SLASH,
                             QUESTION,
                             DOT
                           };
    }

    /**
     * Returns a list of the characters contained in this class.
     * @return a list of the characters contained in this class.
     */
    public static List<Character> getList() {
        
        char[] chars = getArray();
        
        ArrayList<Character> list = new ArrayList<Character>(chars.length);
        
        for (char c : chars) {
            list.add(c);
        }
        
        list.trimToSize();
        
        return list;
    }

    /**
     * Returns a set of the characters contained in this class.
     * @return a set of the characters contained in this class.
     */
    public static Set<Character> getSet() {
        
        char[] chars = getArray();
        
        Set<Character> set = new TreeSet<Character>();
        
        for (char c : chars) {
            set.add(c);
        }
        
        return set;
    }
    
    private SpecialChars() {
        // Prevents instantiation
    }
}
