/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.text.fba;

import sbrt.kernel.fba.Fluxome;
import sbrt.shell.text.Formatter;

/**
 * This interface is used to represent formatters for headers 
 * used in writing files of FBA optimization data.
 * 
 * @author This interface was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 */
public interface FbaOptHeaderFormatter extends Formatter<String> {

    /**
     * Returns the fluxome used to verify reaction names.
     * @return the fluxome used to verify reaction names.
     */
    public Fluxome getFluxome();

	/**
	 * Returns the header used to indicate the value of the
	 * objective function.
	 * 
	 * @return the header used to indicate the value of the
	 * objective function.
	 */
    public String getObjValueHeader();

    /**
     * Indicates if the provided string is the header used
     * to indicate the value of the objective function.
     * 
     * @param s the string to compare.
     * 
     * @return {@code true} if the provided string is equal
     * to the string returned by {@linkplain #getObjValueHeader()};
     * {@code false} otherwise.
     */
    public boolean isObjValueHeader(String s);
}
