/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.text.fba;

import sbrt.kernel.fba.*;
import sbrt.shell.text.*;

/**
 * This class is a concrete implemenation of {@linkplain FluxVectorFormat}.
 * 
 * @author This class was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 */
public class FluxVectorFormatV1 
	extends AbstractMapFormat<String, Double>
        implements FluxVectorFormat {

	private final Fluxome fluxome;
	private final EqualsMapEntryFormatV1<String, String> entryFormat;
	private final PipeSetFormat<String> setFormat;
	private final PipeListFormat<Double> listFormat;
	
	/**
	 * Constructs a new flux vector format.
	 * 
	 * @param fluxome the fluxome to use to verify
	 * reaction names.
	 */
    public FluxVectorFormatV1(Fluxome fluxome) {
    	
    	RxnNameVerifier rv = new RxnNameVerifier(fluxome);
    	DoubleFormatV1 df = new DoubleFormatV1();

    	this.fluxome = fluxome;
        entryFormat = EqualsMapEntryFormatV1.getBasic();
        setFormat = new PipeSetFormat<String>(rv);
        listFormat = new PipeListFormat<Double>(df);
    }

    /**
     * Returns the fluxome used to verify reaction names.
     * @return the fluxome used to verify reaction names.
     */
    public Fluxome getFluxome() {
        return fluxome;
    }

    /**
     * Returns the format used for variable-value pairs.
     * @return the format used for variable-value pairs.
     */
    public EqualsMapEntryFormatV1<String, String> getMapEntryFormat() {
        return entryFormat;
    }

    /**
     * Returns the format used for sets of variables.
     * @return the format used for sets of variables.
     */
    public PipeSetFormat<String> getSetFormat() {
        return setFormat;
    }

    /**
     * Returns the format used for lists of values.
     * @return the format used for lists of values.
     */
    public PipeListFormat<Double> getListFormat() {
        return listFormat;
    }

}
