/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.text.fba;

import java.util.*;

import sbrt.kernel.fba.*;
import sbrt.shell.text.*;

/**
 * This interface is used to represent the formats of collections 
 * of reaction names.
 * 
 * @author This interface was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 */
public interface RxnNameSetFormat extends SimpleFormat<Set<String>> {

	/**
	 * Returns the fluxome used to verify reaction names.
	 * @return the fluxome used to verify reaction names.
	 */
    public Fluxome getFluxome();

	/**
	 * Returns a formatted string representation of the
	 * provided set of reaction names.

	 * @param reactionNames the set of reaction names to be formatted.
	 * 
	 * @return a formatted string representation of the
	 * provided set of reaction names.
	 */
    public String format(Set<String> reactionNames);

    /**
     * Parses the provided string and returns the
     * set of reaction names it contains.
     * 
     * @param reactionNames the string to be parsed.
     * 
     * @return the set of reaction names 
     * contained in the provided string. 
     */
    public LinkedHashSet<String> parse(String reactionNames);
}
