/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.text.math;

import sbrt.shell.text.*;

/**
 * This interface is used to represent the format of 
 * coefficients of mathematical expressions.
 * 
 * @author This interface was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 */
public interface CoeffFormat extends SimpleFormat<Double> {

	/**
	 * Returns a formatted string representation of the
	 * provided coefficient.
	 * 
	 * @param coefficient the coefficient to be formatted.
	 * 
	 * @return a formatted string representation of the
	 * provided coefficient.
	 */
    public String format(Double coefficient);

	/**
	 * Returns a formatted string representation of the
	 * provided coefficient.
	 * 
	 * @param coefficient the coefficient to be formatted.
	 * 
	 * @return a formatted string representation of the
	 * provided coefficient.
	 */
    public String format(double coefficient);

    /**
     * Parses the provided string and returns its 
     * corresponding coefficient.
     * 
     * @param coefficient the string to be parsed.
     * 
     * @return the coefficient corresponding to the 
     * provided string. 
     */
    public Double parse(String coefficient);

    /**
     * Parses the provided string and returns its 
     * corresponding coefficient.
     * 
     * @param coefficient the string to be parsed.
     * 
     * @return the coefficient corresponding to the 
     * provided string. 
     */
    public double parsePrimitive(String coefficient);

}
