/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.text.math;

import sbrt.kernel.math.stat.comp.TauResult;
import sbrt.shell.text.*;

/**
 * This class is a concrete implementation of 
 * {@linkplain CorrResultsFormatter}. The string representation of
 * a correlation results is: {@code Statistic = a | Z = b | n = c}, where
 * {@code a} is the computed statistic, {@code b} is the approximated Z value,
 * and {@code c} is the sample size.
 * 
 * @author This class was written and documented by
 * Jeremiah Wright while in the Wagner lab.
 *
 */
public final class CorrResFormatterV1 implements CorrResultsFormatter<TauResult> {

    private final DoubleFormatV1 doubleFormat;

    /**
     * Constructs a new correlation results formatter.
     */
    public CorrResFormatterV1() {
        doubleFormat = new DoubleFormatV1();
    }

	/**
	 * Returns a formatted string representation of the
	 * provided correlation results.
	 * 
	 * @param results the results to be formatted.
	 * 
	 * @return a formatted string representation of the
	 * provided coefficient.
	 * 
	 * @throws NullPointerException if the provided
	 * coefficient is {@code null}.
	 */
    public String format(TauResult results) {
    	
    	// Creating temporary storage
    	StringBuilder s = new StringBuilder(100);
    	
    	s.append("Statistic = ");
    	s.append(doubleFormat.format(results.getCoeff()));
    	s.append(" | Z = ");
    	s.append(doubleFormat.format(results.getApproxZ()));
    	s.append(" | n = ");
    	s.append(results.getN());
    	
        return s.toString();
    }


}
