/*----------------------------------------------------------------------
-- Copyright (C) 2008 Jeremiah Wright. All rights reserved.
-- E-mail: j.wright@bioc.uzh.ch
--
-- This file is part of the Systems Biology Research Tool (SBRT).
--
-- The SBRT is free software; you can redistribute it and/or modify it
-- under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2, or (at your option)
-- any later version.
--
-- The SBRT is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-- or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
-- License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with the SBRT; see the file COPYING. If not, write to the Free
-- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-- 02111-1307, USA.
----------------------------------------------------------------------*/

package sbrt.shell.text.math;

import sbrt.shell.text.*;
import sbrt.kernel.math.optimization.*;

/**
 * This class is used to represent formats of optimization senses.
 * The strings {@code "Maximize"} and {@code "Minimize"} are used to 
 * represent optimization senses.
 * 
 * @author This class was written and documented by Jeremiah Wright
 * while in the Wagner lab.
 *
 */
public final class SenseFormat implements SimpleFormat<OptSense> {

	private static final String max = "Maximize";
	private static final String min = "Minimize";
	
	/**
	 * Returns a formatted string representation of the
	 * provided optimization sense.
	 * 
	 * @param obj the optimization sense to be formatted.
	 * 
	 * @return a formatted string representation of the
	 * provided optimization sense.
	 */
	public String format(OptSense obj) {

		if (obj == OptSense.MAX) {
			return max;
		}
		
		else if (obj == OptSense.MIN) {
			return min;
		}
		
		else {
			String s = "Not an optimization sense: " + obj;
			throw new IllegalArgumentException(s);
		}
	}

	/**
	 * Parses the provided string and returns its 
	 * corresponding object.
	 * 
	 * @param source the string to be parsed.
	 * 
	 * @return the object corresponding to the 
	 * provided string. 
	 */
	public OptSense parse(String source) {

		// Trimming
		String trimmed = source.trim();
		
		if (trimmed.equalsIgnoreCase(max)) {
			return OptSense.MAX;
		}
		
		if (trimmed.equalsIgnoreCase(min)) {
			return OptSense.MIN;
		}
		
		String s = "The string '" + source + 
		"' is not parsable as an optimization sense.";
		throw new FormatException(s);
	}

}
